@@ -21,9 +21,6 @@
 var {Cc, Ci, Cu, Cm, Cr} = require("chrome");
 var xpcom = require("xpcom");
 
-const HTTPS_EVERYWHERE_REWRITE_TOPIC = "https-everywhere-uri-rewrite";
-
-
 Cu.import("resource://gre/modules/XPCOMUtils.jsm"); 
 
 var observerService = Cc["@mozilla.org/observer-service;1"]
@@ -97,14 +94,25 @@ function TracingListener() {
 TracingListener.prototype = {
 
     onDataAvailable: function(request, context, inputStream, offset, count) {
-        var binaryInputStream = Cc["@mozilla.org/binaryinputstream;1"].
-	    createInstance(Ci.nsIBinaryInputStream);
-        binaryInputStream.setInputStream(inputStream);        
-        var data = binaryInputStream.readBytes(count);
-	this.receivedData.push(data);
+	try {
+	    
+	    // Now, read from the stream  
+	    // This assumes istream is the stream you want to read from  
+	    var scriptableStream = Cc["@mozilla.org/scriptableinputstream;1"]  
+                .createInstance(Ci.nsIScriptableInputStream);  
+	    scriptableStream.init(inputStream);  
+	    var chunk = scriptableStream.read(count);  
+	    this.receivedData.push(chunk);
+
+	} catch (x) {
+
+	    console.log(x, x.lineNumber, x.fileName);
+
+	}
+	
     },
 
-    onStartRequest: function(request, context) {
+    onStartRequest: function(request, context) {	
 	this.receivedData = []; //initialize the array
         this.originalListener.onStartRequest(request, context);
 	this.charset = request.contentCharset;
@@ -143,6 +151,8 @@ observerService.addObserver(httpRequestObserver,
 observerService.addObserver(httpRequestObserver,
 			    "http-on-examine-merged-response", false);
 
+
+
 /* remove observer */
 exports.removeHttpObserver = function () {
 
